@@ -1,7 +1,7 @@
 \unset ECHO
 \i test/setup.sql
 
-SELECT plan(520);
+SELECT plan(628);
 --SELECT * FROM no_plan();
 
 CREATE SCHEMA someschema;
@@ -691,7 +691,7 @@ SELECT * FROM check_test(
 );
 
 /****************************************************************************/
--- Test is_definer().
+-- Test is_definer() isnt_definer().
 SELECT * FROM check_test(
     is_definer( 'public', 'yay', '{}'::name[], 'whatever' ),
     true,
@@ -700,6 +700,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay', '{}'::name[], 'whatever' ),
+    false,
+    'isnt_definer(schema, func, 0 args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay', '{}'::name[] ),
     true,
@@ -708,6 +716,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay', '{}'::name[] ),
+    false,
+    'isnt_definer(schema, func, 0 args)',
+    'Function public.yay() should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
     false,
@@ -716,6 +732,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    true,
+    'isnt_definer(schema, func, args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
     false,
@@ -724,6 +748,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
+    true,
+    'isnt_definer(schema, func, args)',
+    'Function public.oww(integer, text) should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay', 'whatever' ),
     true,
@@ -732,6 +764,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay', 'whatever' ),
+    false,
+    'isnt_definer(schema, func, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay'::name ),
     true,
@@ -740,6 +780,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay'::name ),
+    false,
+    'isnt_definer(schema, func)',
+    'Function public.yay() should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay', '{}'::name[], 'whatever' ),
     true,
@@ -748,6 +796,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay', '{}'::name[], 'whatever' ),
+    false,
+    'isnt_definer(schema, func, 0 args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay', '{}'::name[] ),
     true,
@@ -756,6 +812,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay', '{}'::name[] ),
+    false,
+    'isnt_definer(schema, func, 0 args)',
+    'Function public.yay() should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
     false,
@@ -764,6 +828,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    true,
+    'isnt_definer(schema, func, args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
     false,
@@ -772,6 +844,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'oww', ARRAY['integer', 'text'] ),
+    true,
+    'isnt_definer(schema, func, args)',
+    'Function public.oww(integer, text) should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay', 'whatever' ),
     true,
@@ -780,6 +860,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay', 'whatever' ),
+    false,
+    'isnt_definer(schema, func, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'public', 'yay'::name ),
     true,
@@ -788,6 +876,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'public', 'yay'::name ),
+    false,
+    'isnt_definer(schema, func)',
+    'Function public.yay() should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'yay', '{}'::name[], 'whatever' ),
     true,
@@ -796,6 +892,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'yay', '{}'::name[], 'whatever' ),
+    false,
+    'isnt_definer(func, 0 args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'yay', '{}'::name[] ),
     true,
@@ -804,6 +908,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'yay', '{}'::name[] ),
+    false,
+    'isnt_definer(func, 0 args)',
+    'Function yay() should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'oww', ARRAY['integer', 'text'], 'whatever' ),
     false,
@@ -812,6 +924,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    true,
+    'isnt_definer(func, args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'oww', ARRAY['integer', 'text'] ),
     false,
@@ -820,6 +940,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'oww', ARRAY['integer', 'text'] ),
+    true,
+    'isnt_definer(func, args)',
+    'Function oww(integer, text) should not be security definer',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'yay', 'whatever' ),
     true,
@@ -828,6 +956,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'yay', 'whatever' ),
+    false,
+    'isnt_definer(func, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_definer( 'yay'::name ),
     true,
@@ -836,8 +972,16 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_definer( 'yay'::name ),
+    false,
+    'isnt_definer(func)',
+    'Function yay() should not be security definer',
+    ''
+);
+
 /****************************************************************************/
--- Test is_aggregate().
+-- Test is_aggregate() and isnt_aggregate().
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum', ARRAY['anyelement'], 'whatever' ),
     true,
@@ -846,6 +990,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum', ARRAY['anyelement'], 'whatever' ),
+    false,
+    'isnt_aggregate(schema, func, arg, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum', ARRAY['anyelement'] ),
     true,
@@ -854,6 +1006,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum', ARRAY['anyelement'] ),
+    false,
+    'isnt_aggregate(schema, func, arg)',
+    'Function public.tap_accum(anyelement) should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
     false,
@@ -862,6 +1022,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    true,
+    'isnt_aggregate(schema, func, args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'oww', ARRAY['integer', 'text'] ),
     false,
@@ -870,6 +1038,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'oww', ARRAY['integer', 'text'] ),
+    true,
+    'isnt_aggregate(schema, func, args)',
+    'Function public.oww(integer, text) should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum', 'whatever' ),
     true,
@@ -878,6 +1054,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum', 'whatever' ),
+    false,
+    'isnt_aggregate(schema, func, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum'::name ),
     true,
@@ -886,6 +1070,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum'::name ),
+    false,
+    'isnt_aggregate(schema, func)',
+    'Function public.tap_accum() should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum', ARRAY['anyelement'], 'whatever' ),
     true,
@@ -894,6 +1086,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum', ARRAY['anyelement'], 'whatever' ),
+    false,
+    'isnt_aggregate(schema, func, arg, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum', ARRAY['anyelement'] ),
     true,
@@ -902,6 +1102,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum', ARRAY['anyelement'] ),
+    false,
+    'isnt_aggregate(schema, func, arg)',
+    'Function public.tap_accum(anyelement) should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
     false,
@@ -910,6 +1118,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    true,
+    'isnt_aggregate(schema, func, args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'oww', ARRAY['integer', 'text'] ),
     false,
@@ -918,6 +1134,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'oww', ARRAY['integer', 'text'] ),
+    true,
+    'isnt_aggregate(schema, func, args)',
+    'Function public.oww(integer, text) should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum', 'whatever' ),
     true,
@@ -926,6 +1150,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum', 'whatever' ),
+    false,
+    'isnt_aggregate(schema, func, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'public', 'tap_accum'::name ),
     true,
@@ -934,6 +1166,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'public', 'tap_accum'::name ),
+    false,
+    'isnt_aggregate(schema, func)',
+    'Function public.tap_accum() should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'tap_accum', ARRAY['anyelement'], 'whatever' ),
     true,
@@ -942,6 +1182,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'tap_accum', ARRAY['anyelement'], 'whatever' ),
+    false,
+    'isnt_aggregate(func, arg, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'tap_accum', ARRAY['anyelement'] ),
     true,
@@ -950,6 +1198,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'tap_accum', ARRAY['anyelement'] ),
+    false,
+    'isnt_aggregate(func, arg)',
+    'Function tap_accum(anyelement) should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'oww', ARRAY['integer', 'text'], 'whatever' ),
     false,
@@ -958,6 +1214,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'oww', ARRAY['integer', 'text'], 'whatever' ),
+    true,
+    'isnt_aggregate(func, args, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'oww', ARRAY['integer', 'text'] ),
     false,
@@ -966,6 +1230,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'oww', ARRAY['integer', 'text'] ),
+    true,
+    'isnt_aggregate(func, args)',
+    'Function oww(integer, text) should not be an aggregate function',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'tap_accum', 'whatever' ),
     true,
@@ -974,6 +1246,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'tap_accum', 'whatever' ),
+    false,
+    'isnt_aggregate(func, desc)',
+    'whatever',
+    ''
+);
+
 SELECT * FROM check_test(
     is_aggregate( 'tap_accum'::name ),
     true,
@@ -982,6 +1262,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    isnt_aggregate( 'tap_accum'::name ),
+    false,
+    'isnt_aggregate(func)',
+    'Function tap_accum() should not be an aggregate function',
+    ''
+);
+
 /****************************************************************************/
 -- Test is_strict() and isnt_strict().
 SELECT * FROM check_test(
